local addonInfo, private = ...
local kAlert = private.kAlert
local kUtils = private.kUtils
local kAlertTexts = private.kAlertTexts

local roleChanges = 0
local steps = {}

function steps.step01()
	kAlert.config.messageBox(
		"You appear to be running KaruulAlert for the first time.\rWould you like some help with the initial setup?",
		{ "Yes", "No" },
		steps.step02)
end

function steps.step02(button)
	if button and button ~= 1 then return end
	
	kAlert.systemScanner.start()
	
	roleChanges = 0
	if Event.TEMPORARY and Event.TEMPORARY.Role then
		kUtils.subscribeEvent(Event.TEMPORARY.Role, function() roleChanges = roleChanges + 1 end, "kAlert", "gettingStarted")
	end	
	
	kAlert.config.messageBox(
		"Before you can set up alerts, KaruulAlert needs to learn about your character's abilities.\r" ..
		"Please find a safe place and switch to every role you have.",
		{ "Continue", "Cancel" },
		steps.step03)
end

function steps.step03(button)
	kUtils.unsubscribeEvent(Event.TEMPORARY.Role, "kAlert", "gettingStarted")
	if button and button ~= 1 then return end
	
	if roleChanges == 0 then
		kAlert.config.messageBox(
			"You have not switched roles to allow KaruulAlert to learn all about your character.\r" ..
			"Try again?",
			{ "Try Again", "Continue", "Cancel" },
			steps.step03b)
	else
		kAlert.config.messageBox(
			"KaruulAlert should now know all about your abilities.\r" ..
			"It will automatically learn about different buffs as you play.\r" ..
			"If you enable the ability scanner, KaruulAlert will learn faster.\r" ..
			"It will also notify you when it finds a new buff.\r" ..
			"Try it now, select some other players that have interesting buffs.",
			{ "Continue", "Cancel" },
			steps.step04)
		
	end
end

function steps.step04(button)
	if button and button ~= 1 then return end

	kAlert.config.messageBox(
		"You are now ready to set up some alerts.\r" ..
		"Would you like to open the configuration dialog now?",
		{ "OK", "Cancel" },
		steps.step05)
end

function steps.step05(button)
	if button == 1 then
		kAlert.config.main()
	end

	kAlert.config.messageBox(
		"To open up the configuration dialog, type in the /kalert command.\r" ..
		"For more explanation about a specific subject, type /kalert help.",
		{ "Continue", "Cancel" },
		steps.step06)
end

function steps.step06(button)
	if button and button ~= 1 then return end

	kAlert.config.messageBox(
		"Alerts are organized into sets.\r" ..
		"You can set up one set for each role you play, plus up to 10 sub sets.\r" ..
		"Only one set and one sub set can be active at the same time.",
		{ "OK", "Cancel" },
		steps.step07)
end

function steps.step06(button)
	if button and button ~= 1 then return end

	kAlert.config.messageBox(
		"This concludes the tutorial for KaruulAlert.\r" ..
		"Please ready the online help for information on setting up different alert types\r" ..
		"Would you like to open the online help now?",
		{ "Yes Please", "No Thanks" },
		steps.step08)
end

function steps.step08(button)
	if button and button ~= 1 then return end
	kAlert.config.help()
end


function steps.step03b(button)
	if button == 1 then
		steps.step02()
	elseif button == 2 then
		roleChanges = -1
		steps.step03()
	end
end



function kAlert.gettingStarted(firstTime)
	if firstTime then
		steps.step01()
	else
		steps.step02()
	end
end

